package store

import (
	"errors"
	"net/url"
	"regexp"
)

const letters = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"

var (
	nameRegex   = regexp.MustCompile(`^[a-z0-9()_-]{3,}$`)
	sha256Regex = regexp.MustCompile(`\b[A-Fa-f0-9]{64}\b`)
	secretRegex = regexp.MustCompile(`\b[A-Za-z]{64}\b`)
)

var (
	// AlreadyExists is returned when store already exists.
	AlreadyExists = errors.New("store path already exists")
)

// MatchName determines if str is a valid name.
func MatchName(str string) bool {
	return nameRegex.MatchString(str)
}

// MatchURL determines if str is a valid URL.
func MatchURL(str string) bool {
	u, err := url.Parse(str)
	return err == nil && u.Scheme != "" && u.Host != ""
}

// These two really shouldn't be methods... Maybe change that for v2.

// MatchName determines if str is a valid name. As of v1, this just calls MatchName.
func (s *Store) MatchName(str string) bool {
	return MatchName(str)
}

// MatchURL determines if str is a valid URL. As of v1, this just calls MatchURL.
func (s *Store) MatchURL(str string) bool {
	return MatchURL(str)
}
